@@ -11,6 +11,7 @@ from django.core.exceptions import ValidationError
 from django.core.exceptions import NON_FIELD_ERRORS
 from django.core.validators import validate_email
 
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 from django.template.defaultfilters import slugify
 from django.contrib.auth.models import User
@@ -28,7 +29,7 @@ def is_valid_identifier(identifier):
         return False
     return True
 
-
+@python_2_unicode_compatible
 class Worker(models.Model):
     ACCESS_REQUEST_TIMEOUT = 1
 
@@ -93,10 +94,11 @@ class Worker(models.Model):
         return ('core_worker_detail', (), {
             'slug': self.slug})
 
-    def __unicode__(self):
-        return str(self.title)
+    def __str__(self):
+        return self.title
 
 
+@python_2_unicode_compatible
 class Task(models.Model):
     unique_identifier = models.CharField(max_length=255, null=True, blank=True, help_text="Unique Identifier to group multiple Task Versions")
     version_major = models.PositiveIntegerField(null=True, blank=True, default=0)
@@ -208,10 +210,10 @@ class Task(models.Model):
         return ('core_task_detail', (), {
             'slug': self.slug})
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title or self.desc or str(self.pk)
 
-
+@python_2_unicode_compatible
 class Workflow(models.Model):
     unique_identifier = models.CharField(max_length=255, null=True, blank=True, help_text="Unique Identifier to group multiple Workflow Versions")
     version_major = models.PositiveIntegerField(null=True, blank=True, default=0)
@@ -255,10 +257,11 @@ class Workflow(models.Model):
         return ('core_workflow_detail', (), {
             'slug': self.slug})
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title or self.desc or str(self.pk)
 
 
+@python_2_unicode_compatible
 class WorkflowPreset(models.Model):
     workflow = models.ForeignKey(Workflow, verbose_name=_("Workflow"))
     user = models.ForeignKey(User, verbose_name=("User"))
@@ -308,10 +311,11 @@ class WorkflowPreset(models.Model):
 
         return not errors
 
-    def __unicode__(self):
+    def __str__(self):
         return "Preset for %s (%s)" % (self.workflow, self.user)
 
 
+@python_2_unicode_compatible
 class WorkflowTask(models.Model):
     workflow = models.ForeignKey(Workflow, verbose_name=_("Workflow"))
     task = models.ForeignKey(Task, verbose_name=_("Task"))
@@ -336,7 +340,7 @@ class WorkflowTask(models.Model):
 
         super(WorkflowTask, self).delete(*args, **kwargs)  # Call the "real" save() method
 
-    def __unicode__(self):
+    def __str__(self):
         if self.prev_workflow_task:
             s = str(self.prev_workflow_task.task.slug)
         else:
@@ -348,6 +352,7 @@ class WorkflowTask(models.Model):
         return "%s: %s -(%s)-> %s" % (str(self.workflow), str(s), str(self.task.slug), str(n))
 
 
+@python_2_unicode_compatible
 class WorkflowLog(models.Model):
     SUCCESS = 0
     ERROR = 1
@@ -375,12 +380,12 @@ class WorkflowLog(models.Model):
 
     @models.permalink
     def get_absolute_url(self):
-        return ('core_wokflow_log_detail', (), {
+        return ('core_workflow_log_detail', (), {
             'slug': self.workflow.slug,
             'id': self.id})
 
-    def __unicode__(self):
-        return "[%s] %s logged %s"[:50] % (self.date_created.strftime('%d.%m.%y'), str(self.performed_by), self.workflow.title, )
+    def __str__(self):
+        return "%s - %s logged %s" % (self.date_created.strftime('%d.%m.%y %M:%H'), str(self.performed_by), self.workflow.title, )
 
 
 class Parameter(models.Model):
@@ -426,6 +431,7 @@ class Parameter(models.Model):
             pass
 
 
+@python_2_unicode_compatible
 class UserParameter(Parameter):
     owner = models.ForeignKey(User, help_text="Parameter owner")
 
@@ -455,7 +461,7 @@ class UserParameter(Parameter):
                     }
                 )
 
-    def __unicode__(self):
+    def __str__(self):
         return "%s:%s (%s)" % (self.data_type, self.name, self.owner)
 
     @models.permalink
@@ -464,6 +470,7 @@ class UserParameter(Parameter):
             'id': self.id})
 
 
+@python_2_unicode_compatible
 class OrganizationParameter(Parameter):
     owner = models.ForeignKey(Organization, help_text="Parameter owner")
 
@@ -493,7 +500,7 @@ class OrganizationParameter(Parameter):
                     }
                 )
 
-    def __unicode__(self):
+    def __str__(self):
         return "%s:%s (%s)" % (self.data_type, self.name, self.owner)
 
     @models.permalink
@@ -503,6 +510,7 @@ class OrganizationParameter(Parameter):
             'id': self.id})
 
 
+@python_2_unicode_compatible
 class ParameterList(models.Model):
     """
     ParameterList
@@ -518,4 +526,7 @@ class ParameterList(models.Model):
         ordering = ['title', 'date_created', ]
         verbose_name = _("Parameter List")
         verbose_name_plural = _("Parameter Lists")
+        
+    def __str__(self):
+        return self.title
 
