@@ -22,12 +22,12 @@ urlpatterns = patterns('threebot.views',
     url(r'^task/$', view='task.list', name='core_task_list'),
 
     url(r'^workflow/add/$', view='workflow.create', name='core_workflow_create'),
-    url(r'^workflow/(?P<slug>[-\w]+)/log/(?P<id>[-\w]+)/$', view='workflow.log_detail', name='core_wokflow_log_detail'),
-    url(r'^workflow/(?P<slug>[-\w]+)/log/(?P<id>[-\w]+)/replay/$', view='workflow.replay', name='core_wokflow_replay'),
+    url(r'^workflow/(?P<slug>[-\w]+)/log/(?P<id>[-\w]+)/$', view='workflow.log_detail', name='core_workflow_log_detail'),
+    url(r'^workflow/(?P<slug>[-\w]+)/log/(?P<id>[-\w]+)/replay/$', view='workflow.replay', name='core_workflow_replay'),
 
     url(r'^workflow/(?P<slug>[-\w]+)/delete/$', view='workflow.delete', name='core_workflow_delete'),
     url(r'^workflow/(?P<slug>[-\w]+)/digest/$', view='workflow.detail_digest', name='core_workflow_detail_digest'),
-    url(r'^workflow/(?P<slug>[-\w]+)/reorder/$', view='workflow.detail_reorder', name='core_wokflow_detail_reorder'),
+    url(r'^workflow/(?P<slug>[-\w]+)/reorder/$', view='workflow.detail_reorder', name='core_workflow_detail_reorder'),
     url(r'^workflow/(?P<slug>[-\w]+)/edit/$', view='workflow.detail_edit', name='core_workflow_detail_edit'),
     url(r'^workflow/(?P<slug>[-\w]+)/with-list/$', view='workflow.detail_perf_with_list', name='core_workflow_detail_with_list'),
     url(r'^workflow/(?P<slug>[-\w]+)/$', view='workflow.detail_perf', name='core_workflow_detail'),
